<?php
/**
 * This file defines a new class Tantyyellow_Custom_Walker_Nav_Menu.
 * In order to re-define header navigation menu
 *
 * @package tantyyellow
 */

// ########################################################################################################################
// ##### In order to re-define header navigation menu #####################################################################
// ########################################################################################################################

/**
 * CUSTOM NAV MENU WALKER
 * In order to change the structure of header navigation menu.
 *
 * 01.'lvl(level)' means 'hierarchy' which doesn't react to the first hierarchy
 * - 'start_lvl' => commonly outputing <ul>
 * - 'end_lvl'   => commonly outputing </ul>
 *
 * 02.'el' means 'element' which react to each menu item
 * - 'start_lvl' => commonly outputing <ul>
 * - 'end_lvl'   => commonly outputing </ul>
 *
 * @see wp-includes/class-walker-nav-menu.php
 */
class Tantyyellow_Custom_Walker_Nav_Menu extends Walker_Nav_Menu {
	/**
	 * Starts the list before the elements are added.
	 *
	 * Adds classes to the unordered list sub-menus.
	 *
	 * @see Walker::Walker_Nav_Menu::start_lvl()
	 *
	 * @param string   $output Used to append additional content (passed by reference).
	 * @param int      $depth  Depth of menu item. Used for padding.
	 * @param stdClass $args   An object of wp_nav_menu() arguments.
	 */
	public function start_lvl( &$output, $depth = 0, $args = array() ) {

		$indent  = str_repeat( "\t", $depth + 9 );
		$classes = array(
			'sidebar-submenu',
			'dropdown-menu',
			'sub-menu',
			'menu-item-depth-' . (string) ( (int) $depth + 1 ),

		);
		$class_names = esc_attr( implode( ' ', $classes ) );

		// Build HTML for output.
		$output .= "\n" . $indent . '<ul class="' . $class_names . '" aria-labelledby="navbarDropdown">' . "\n";
	}

	/**
	 * Ends the list of after the elements are added.
	 *
	 * @see Walker::Walker_Nav_Menu::end_lvl()
	 *
	 * @param string   $output Used to append additional content (passed by reference).
	 * @param int      $depth  Depth of menu item. Used for padding.
	 * @param stdClass $args   An object of wp_nav_menu() arguments.
	 */
	public function end_lvl( &$output, $depth = 0, $args = array() ) {
		// Depth-dependent classes.
		$indent = str_repeat( "\t", $depth + 9 );

		// Build HTML for output.
		$output .= "\n" . $indent . '</ul>' . "\n";
	}

	/**
	 * Starts the element output.
	 *
	 * @see Walker::Walker_Nav_Menu::start_el()
	 *
	 * @param string   $output Used to append additional content (passed by reference).
	 * @param WP_Post  $item   Menu item data object.
	 * @param int      $depth  Depth of menu item. Used for padding.
	 * @param stdClass $args   An object of wp_nav_menu() arguments.
	 * @param int      $id     Current item ID.
	 */
	public function start_el( &$output, $item, $depth = 0, $args = null, $id = 0 ) {

		$indent_for_li     = str_repeat( "\t", 8 );
		$indent_for_anchor = str_repeat( "\t", $depth + 9 );

		// If top-menu.
		if ( 0 === $depth ) {
			// Depth-dependent classes.
			$depth_classes = array(
				'nav-item',
				'main-menu-item',
				'menu-item-depth-' . $depth,
			);

			// Add class="dropdown" to the element which includes class="menu-item-has-children", which means it has sub-menu.
			if ( in_array( 'menu-item-has-children', (array) $item->classes, true ) ) {
				$depth_classes[] .= 'dropdown sidebar-dropdown';
			}
			$depth_class_names = esc_attr( implode( ' ', $depth_classes ) );

			// Passed classes.
			$classes = empty( $item->classes ) ? array() : (array) $item->classes;

			/**
			 * The path in which the function "apply_filters" is defined.
			 * - When a function is not added for the hook name ( in this case, 'tantyyellow_nav_menu_css_class' ) by using add_filter(),
			 * - apply_filters() return the second parameter which comes after the hook name.
			 *
			 * @see wp-includes\plugin.php line:192
			 */
			$class_names = esc_attr( implode( ' ', apply_filters( 'tantyyellow_nav_menu_css_class', array_filter( $classes ), $item ) ) );

			// Build HTML.
			$output .= "\n" . $indent_for_li . '<li id="nav-menu-item-' . $item->ID . '" class="' . $depth_class_names . ' ' . $class_names . '">' . "\n" . $indent_for_anchor;

			// <a> tag's attributes.
			$attributes  = ! empty( $item->attr_title ) ? ' title="' . esc_attr( $item->attr_title ) . '"' : '';
			$attributes .= ! empty( $item->target ) ? ' target="' . esc_attr( $item->target ) . '"' : '';
			$attributes .= ! empty( $item->xfn ) ? ' rel="' . esc_attr( $item->xfn ) . '"' : '';
			// href attribute.
			if ( in_array( 'menu-item-has-children', (array) $item->classes, true ) ) { // If $item has sub-menu.

				// 01. Delete link URL from <a> tag when it has child menu.
				// $attributes .= ' href="#"';

				// 02. Keep link URL active in <a> tag even when it has child menu.
				$attributes .= ' href="' . esc_attr( $item->url ) . '"';

			} else {
				$attributes .= ! empty( $item->url ) ? ' href="' . esc_attr( $item->url ) . '"' : '';
			}
			// etc. attributes ( Checking if "$item is the first menu element" and if "$item has sub-menu" ).
			if ( in_array( 'menu-item-home', (array) $item->classes, true ) ) {

				if ( in_array( 'menu-item-has-children', (array) $item->classes, true ) ) {
					$attributes .= ' class="nav-link menu-link main-menu-link" data-target=".navbar-collapse.show" data-toggle="dropdown" role="button" aria-expanded="false" aria-haspopup="true"';

				} else {
					$attributes .= ' class="nav-link menu-link main-menu-link" data-target="navbar-collapse.show" data-toggle=""';
				}
			} else {
				if ( in_array( 'menu-item-has-children', (array) $item->classes, true ) ) {
					$attributes .= ' class="nav-link menu-link main-menu-link" data-toggle="dropdown" role="button" aria-expanded="false" aria-haspopup="true"';
				} else {
					$attributes .= ' class="nav-link menu-link main-menu-link"';
				}
			}

			/**
			 * Use the theme unique hook name "tantyyellow_the_title".
			 *
			 * - The hook name "the_title" is used in the parent class ( Walker_Nav_Menu ) of "Tantyyellow_Custom_Walker_Nav_Menu".
			 * - However, a hook name must start from the theme prefix name, it is not allowed to use "the_title" as it is.
			 *
			 * - Therefore, define a theme unique hook name 'tantyyellow_the_title' and assigned the same functions
			 *   as those 'the_title' hooks in WP core file as default.
			 *
			 * @see functions\setups.php line:332
			 * @see wp-includes\default-filters.php line:168
			 */
			// Build HTML output and pass through the proper filter.
			$item_output = sprintf(
				'%1$s<a%2$s><span>%3$s%4$s%5$s</span><div><div></div></div></a>%6$s',
				$args->before,
				$attributes,
				$args->link_before,
				apply_filters( 'tantyyellow_the_title', $item->title, $item->ID ),
				$args->link_after,
				$args->after
			);
			$output     .= apply_filters( 'tantyyellow_walker_nav_menu_start_el', $item_output, $item, $depth, $args );

			// If sub-menu(dropdown-menu).
		} else {
			// Depth-dependent classes.
			$depth_classes     = array(
				'nav-item',
				'main-menu-item',
				'menu-item-depth-' . $depth,
			);
			$depth_class_names = esc_attr( implode( ' ', $depth_classes ) );

			// Passed classes.
			$classes     = empty( $item->classes ) ? array() : (array) $item->classes;
			$class_names = esc_attr( implode( ' ', apply_filters( 'tantyyellow_nav_menu_css_class', array_filter( $classes ), $item ) ) );

			$output .= "\n" . $indent_for_li . '<li id="nav-menu-item-' . $item->ID . '" class="' . $depth_class_names . ' ' . $class_names . '">' . "\n" . $indent_for_anchor;

			// Link attributes.
			$attributes  = ! empty( $item->attr_title ) ? ' title="' . esc_attr( $item->attr_title ) . '"' : '';
			$attributes .= ! empty( $item->target ) ? ' target="' . esc_attr( $item->target ) . '"' : '';
			$attributes .= ! empty( $item->xfn ) ? ' rel="' . esc_attr( $item->xfn ) . '"' : '';
			$attributes .= ! empty( $item->url ) ? ' href="' . esc_attr( $item->url ) . '"' : '';
			$attributes .= ' class="dropdown-item menu-link sub-menu-link"';

			if ( in_array( 'menu-item-has-children', (array) $item->classes, true ) ) {
				$attributes .= ' class="nav-link menu-link main-menu-link" data-target=".navbar-collapse.show" data-toggle="dropdown" role="button" aria-expanded="false" aria-haspopup="true"';

			} else {
				$attributes .= ' class="nav-link menu-link main-menu-link" data-target="navbar-collapse.show" data-toggle=""';
			}

			// Build HTML output and pass through the proper filter.
			$item_output = sprintf(
				'%1$s<a%2$s><span>%3$s%4$s%5$s</span></a>%6$s',
				$args->before,
				$attributes,
				$args->link_before,
				apply_filters( 'tantyyellow_the_title', $item->title, $item->ID ),
				$args->link_after,
				$args->after
			);
			$output     .= apply_filters( 'tantyyellow_walker_nav_menu_start_el', $item_output, $item, $depth, $args );
		}

	}

	/**
	 * Ends the element output, if needed.
	 *
	 * @see Walker::Walker_Nav_Menu::end_el()
	 *
	 * @param string   $output Used to append additional content (passed by reference).
	 * @param WP_Post  $item   Page data object. Not used.
	 * @param int      $depth  Depth of page. Not Used.
	 * @param stdClass $args   An object of wp_nav_menu() arguments.
	 */
	public function end_el( &$output, $item, $depth = 0, $args = array() ) {
		$indent = str_repeat( "\t", 8 );
		if ( 0 === $depth ) {
			$output .= "\n" . $indent . '</li>';
		} else {
			$output .= '';
		}
	}
}
