<?php
/**
 * This file contains a set of functions in order to output HTML DOM content.
 *
 * @package tantyyellow
 */

// ########################################################################################################################
// ##### Functions in order to output HTML ################################################################################
// ########################################################################################################################



// ***** In order to output "Skip link" button at the top of the page *******************************************

/**
 * Output "Skip link" button at the top of the page.
 */
function tantyyellow_output_skip_link_button() {
	echo '
		<a id="skip_to_the_content_btn" class="skip-link screen-reader-text" href="#contents-main" aria-label="' . esc_attr__( 'Click this link to skip global navigation menu and widgets sidebar in order to move on to the main content directly.', 'tantyyellow' ) . '">' .
			esc_attr__( 'Skip to Main Content', 'tantyyellow' ) .
		'</a>
	';
}

add_action( 'wp_body_open', 'tantyyellow_output_skip_link_button', 5 );



// ***** In order to add attribute "aria-label" in the custom logo **********************************************

/**
 * Add attribute "aria-label" in the custom logo.
 *
 * @param array $attr Custom logo image attributes.
 *
 * @link https://developer.wordpress.org/reference/hooks/get_custom_logo_image_attributes/
 * @link https://wordpress.stackexchange.com/questions/229905/how-to-add-css-class-to-custom-logo/229910#answer-229911
 */
function tantyyellow_add_arialabel_attr_to_custom_logo( $attr ) {
	$attr['aria-label'] = esc_attr__( 'Click this header logo to return the site homepage', 'tantyyellow' );
	return $attr;
}
add_filter( 'wp_get_attachment_image_attributes', 'tantyyellow_add_arialabel_attr_to_custom_logo' );



// ***** In order to add id to <body> ***************************************************************************

/**
 * Add a unique id to <body>.
 *
 * @link https://developer.wordpress.org/reference/functions/get_post_field/ get_post_field()
 * @link https://developer.wordpress.org/reference/functions/get_post/       get_post()
 * @link https://wordpress.stackexchange.com/questions/42117/how-do-i-retrieve-the-slug-of-the-current-page#answer-188926
 */
function tantyyellow_add_id_to_body_tag() {

	$prefix = '';
	$title  = '';

	if ( is_archive() ) :

		$prefix .= 'archive_';

		if ( is_category() ) {
			$prefix .= 'category_';

		} elseif ( is_tag() ) {
			$prefix .= 'tag_';

		} elseif ( is_author() ) {
			$prefix .= 'author_';

		} elseif ( is_day() ) {
			$prefix .= 'day_';

		} elseif ( is_month() ) {
			$prefix .= 'month_';

		} elseif ( is_year() ) {
			$prefix .= 'year_';
		}

		$title .= 'page_for_' . get_the_archive_title();

	elseif ( is_search() ) :

		$prefix .= 'search_result_page_for_keyword_';

		$search_query_str = get_search_query( true );

		/**
		 * Replace all white spaces with Hyphens.
		 *
		 * @link https://www.w3schools.com/php/func_regex_preg_replace.asp                                  PHP preg_replace() Function
		 * @link https://www.w3schools.com/php/func_string_str_replace.asp                                  PHP str_replace() Function
		 * @link https://stackoverflow.com/questions/5245513/php-preg-replace-preg-match-vs-php-str-replace preg_match vs PHP str_replace
		 * @link https://stackoverflow.com/questions/8175655/preg-replace-all-spaces#answer-8175678         unicode modifier
		 */
		$search_query_str = preg_replace( '/\s+/', '_', $search_query_str );
		$search_query_str = str_replace( ' ', '_', $search_query_str );

		$title .= ( empty( $search_query_str ) ) ? '' : $search_query_str;

	elseif ( is_404() ) :

		$prefix .= 'not_found_';
		$title  .= '404_';

	else :

		if ( is_single() ) {
			$prefix .= 'single_post_page_';

		} elseif ( is_home() ) {
			$prefix .= 'posts_page_';

		} else {
			$prefix .= 'page_';
		}

		$gotten_title = wp_strip_all_tags( get_the_title() );

		// Remove all whitespaces.
		$gotten_title = preg_replace( '/\s+/', '_', $gotten_title );
		$gotten_title = str_replace( ' ', '_', $gotten_title );

		$title .= $gotten_title;

	endif;

	$site_title = get_bloginfo( 'name' );

	$site_name = empty( $site_title ) ? get_template() : $site_title;
	$site_name = preg_replace( '/\s+/', '_', $site_name );
	$site_name = str_replace( ' ', '_', $site_name );

	$output = $site_name . '_' . $prefix . $title . '_id';
	$output = sanitize_html_class( $output );
	$output = preg_replace( '/(_){2,}/', '_', $output );

	echo esc_attr( $output );
}



// ***** In order to add classes to <body> **********************************************************************

/**
 * Define function for filter hook "tantyyellow_add_classes_to_body_tag".
 *
 * @param array $classes The class names to be added to body tag.
 *
 * @link https://developer.wordpress.org/reference/functions/body_class/
 */
function tantyyellow_add_classes_to_body_tag( $classes ) {

	/* ===== Add classes for "Site locale" & "Site language" ==================================== */
	$locale       = get_locale();
	$class_locale = 'site_locale_' . $locale;

	$lang       = ( strpos( $locale, '_' ) ) ? strstr( $locale, '_', true ) : $locale;
	$class_lang = 'site_lang_' . $lang;

	$classes = array_merge( $classes, array( $class_locale, $class_lang ) );

	/* ===== Add classes for value(on/off) of "auto-close expanded elements" ==================== */
	$left_burger     = 'ac_expdd_left_burger_' . tantyyellow_get_site_basics_auto_close_expanded_left_burger_menu_onoff_value();
	$right_widgets   = 'ac_expdd_right_widgets_' . tantyyellow_get_site_basics_auto_close_expanded_right_widgets_sidebar_onoff_value();
	$single_cats     = 'ac_expdd_single_cats_' . tantyyellow_get_site_basics_auto_close_expanded_single_page_cats_list_onoff_value();
	$single_tags     = 'ac_expdd_single_tags_' . tantyyellow_get_site_basics_auto_close_expanded_single_page_tags_list_onoff_value();
	$single_related  = 'ac_expdd_single_related_' . tantyyellow_get_site_basics_auto_close_expanded_single_page_related_posts_onoff_value();
	$single_comments = 'ac_expdd_single_comments_' . tantyyellow_get_site_basics_auto_close_expanded_single_page_comments_onoff_value();
	$single_pings    = 'ac_expdd_single_pings_' . tantyyellow_get_site_basics_auto_close_expanded_single_page_pings_onoff_value();

	$classes = array_merge( $classes, array( $left_burger, $right_widgets ) );

	if ( is_single() ) {
		$classes = array_merge( $classes, array( $single_cats, $single_tags, $single_related, $single_comments, $single_pings ) );
	}

	/* ========================================================================================== */
	return $classes;
}
add_filter( 'body_class', 'tantyyellow_add_classes_to_body_tag' );



// ***** Template parts for 'loop' ******************************************************************************

/**
 * Output the sub loop each post.
 *
 * @param string $details_link Switch the visibility of the post's details link.
 * @param string $loop_type    The type of WordPress loop ( sub loop or main loop ).
 *
 * @return void
 */
function tantyyellow_output_loop_sub_each_post( $details_link, $loop_type ) {

	global $post;
	?>

	<!-- <div class="posts-loop-wrapper"> -->

		<article id="post-<?php the_ID(); ?>" <?php post_class( 'post-loop excerpted-post' ); ?>>

			<header class="each-post-header">

				<div class="each-post-header-inner">

					<!-- Each post information -->
					<?php tantyyellow_output_template_parts_loop_each_post_infos( 'with-post-title', 'with-post-dates' ); ?>

					<!-- Each post background image. -->
					<?php tantyyellow_output_template_parts_loop_each_post_thumbnail_image( '' ); ?>

				</div>

			</header><!-- /.each-post-header -->

			<div class="each-post-main">

				<!-- Each post meta information -->
				<?php tantyyellow_output_template_parts_loop_each_post_meta_infos(); ?>

				<!-- Each post content -->
				<?php
				tantyyellow_output_template_parts_loop_each_post_content( $post->post_content, $details_link, $loop_type );
				?>

			</div><!-- /.each-post-main -->

		</article><!-- /.posts-loop -->

	<!-- </div> --><!-- /.posts-loop-wrapper -->

	<?php
}



/**
 * Output each post information, including...
 * ( post's title, published & modified dates, edit link for admin user )
 *
 * @param string $post_title Switch the visibility of the post's title.
 * @param string $post_dates Switch the visibility of the post's dates.
 *
 * @return void
 */
function tantyyellow_output_template_parts_loop_each_post_infos( $post_title, $post_dates ) {

	/* If a user is being logged in, or the page is neither "Static Page" nor "Attachment Page"... */
	if ( is_user_logged_in() || ( ! ( is_page() || is_attachment() ) ) ) :

		if ( is_page() ) {
			$class_str = ' each_post_info_is_page';
		} elseif ( is_attachment() ) {
			$class_str = ' each_post_info_is_attachment';
		} else {
			$class_str = '';
		}
		?>

		<!-- Each post information -->
		<div class="each-post-info<?php echo esc_attr( $class_str ); ?>">

			<?php
			/* In order not to display title if it is a single post page */
			if ( 'with-post-dates' === $post_dates ) :
				?>

			<p class="each-post-dates">
				<time>
					<?php
					if ( get_the_modified_date( 'U' ) !== get_the_date( 'U' ) ) :
						$mod_year  = get_the_modified_date( 'Y' );
						$mod_month = get_the_modified_date( 'm' );
						$mod_date  = get_the_modified_date( 'j' );
						?>
					<a href="<?php echo esc_url( get_day_link( $mod_year, $mod_month, $mod_date ) ); ?>" aria-label="<?php echo esc_attr__( 'This post\'s most recent-updated date is ', 'tantyyellow' ) . esc_html( get_the_modified_date( 'Y.m.d' ) ); ?>">
						<span class="each-post-date-modified">
							<?php echo esc_html( get_the_modified_date( 'Y.m.d' ) ); // Display updated date. ?>
						</span>
					</a>

						<?php
					endif;

					$pub_year  = get_the_date( 'Y' );
					$pub_month = get_the_date( 'm' );
					$pub_date  = get_the_date( 'j' );
					?>

					<a href="<?php echo esc_url( get_day_link( $pub_year, $pub_month, $pub_date ) ); ?>" aria-label="<?php echo esc_attr__( 'This post\'s first-published date is ', 'tantyyellow' ) . esc_html( get_the_date( 'Y.m.d' ) ); ?>">
						<span class="each-post-date-published">
							<?php
							// In order to get the string of the published date.
							// 'the_date()' doesn't output the same date more than twice ( Only the first post is displayed ).
							echo esc_html( get_the_date( 'Y.m.d' ) );
							?>
						</span>
					</a>
				</time>
			</p>

				<?php
			endif;

			/* In order not to display title if it is a single post page */
			if ( 'with-post-title' === $post_title ) :
				?>

				<h2 class="each-post-title font-family_heading_level<?php echo ( 'ja' === get_locale() ) ? ' font_weight_bold' : ''; ?>">
					<a href="<?php echo esc_url( get_permalink() ); ?>" aria-label="<?php echo ( get_the_title() ) ? ( esc_attr__( 'The title of this post is ', 'tantyyellow' ) ) . esc_attr( wp_strip_all_tags( get_the_title() ) ) : 'This post has no title'; ?>">
						<?php
						if ( get_the_title() ) :
							echo wp_kses_post( get_the_title() );
						else :
							esc_html_e( 'No Title', 'tantyyellow' );
						endif;
						?>
					</a>
				</h2>

				<?php
			endif;

			if ( is_user_logged_in() ) :

				if ( is_single() ) {
					?>
					<p class="each-post-edit-link">
						<a class="post-edit-link" href="<?php echo esc_url( get_edit_post_link() ); ?>" target="_blank" aria-label="<?php echo esc_attr__( 'Click this link to move on to this post\'s editing page', 'tantyyellow' ); ?>"><?php esc_html_e( 'Edit', 'tantyyellow' ); ?></a>
					</p>
					<?php
				}
			endif;
			?>

		</div><!-- /.each-post-info -->

		<?php
	endif; // End of "if ( is_user_logged_in() || ( ! ( is_page() || is_attachment() ) ) )".
}



/**
 * Output each post thumbnail image
 *
 * @param string $thumbnail_size The post thumbnail image size. Set '' for default size.
 *
 * @return void
 */
function tantyyellow_output_template_parts_loop_each_post_thumbnail_image( $thumbnail_size ) {
	?>
	<div class="each-post-bg-img single-page-img">
		<?php
		if ( has_post_thumbnail() ) :
			the_post_thumbnail( $thumbnail_size );

		else :
			$default_featured_img_url = tantyyellow_get_site_basics_posts_subsection_all_posts_site_default_featured_img_url();
			$default_no_img_path      = get_theme_file_uri( '/src/assets/media-files/images/default_images/default_no_image.jpg' );
			$img_path                 = ( $default_featured_img_url ) ? $default_featured_img_url : $default_no_img_path;
			?>
			<img src="<?php echo esc_url( $img_path ); ?>" alt="<?php bloginfo( 'name' ); ?> Default Image">

			<?php
		endif;
		?>
	</div>
	<?php
}



/**
 * Output each post meta information, including...
 * ( post's categories, tags )
 * ( author, comments number ) if the page is single page
 *
 * @return void
 */
function tantyyellow_output_template_parts_loop_each_post_meta_infos() {

	$meta_info_single_page   = tantyyellow_get_site_basics_posts_each_post_single_page_meta_info_visibility_onoff_value();
	$meta_info_archive_pages = tantyyellow_get_site_basics_posts_each_post_archive_pages_meta_info_visibility_onoff_value();

	if (
		( is_single() && ( 'show' === $meta_info_single_page ) ) ||
		( ( ! is_single() ) && ( 'show' === $meta_info_archive_pages ) )
	) :
		?>
		<div class="each-post-meta font-family_subheading_level clearfix">

			<!-- Each post all categories -->
			<p class="each-post-meta-primary">
				<span class="each-post-meta-name"><?php esc_html_e( 'CATEGORY', 'tantyyellow' ); ?></span>
				<?php
				if ( has_category() ) :
					?>
					<span class="each-post-meta-info" aria-label="<?php esc_attr_e( 'This Post\'s Category', 'tantyyellow' ); ?>">
						<?php
						$categories = get_the_category();
						if ( ! empty( $categories ) ) {
							printf(
								/* translators: %s: category page URL & the name of the post's first category. */
								'<a href="%s" aria-label="' . esc_attr__( 'This Post is in the category named: %s', 'tantyyellow' ) . '">%s</a>',
								esc_url( get_category_link( $categories[0]->term_id ) ),
								esc_html( $categories[0]->cat_name ),
								esc_html( $categories[0]->cat_name )
							);
						}
						?>
					</span>
					<?php

				else :
					?>
					<span class="each-post-meta-info no-meta-info">
						<a tabindex="0" aria-label="<?php esc_attr_e( 'This Post is in no category', 'tantyyellow' ); ?>">( <?php esc_html_e( 'None', 'tantyyellow' ); ?> )</a>

					</span>
					<?php

				endif;
				?>
			</p>

			<!-- Each post all tags -->
			<p class="each-post-meta-secondary">
				<span class="each-post-meta-name"><?php esc_html_e( 'TAGS', 'tantyyellow' ); ?></span>
				<?php
				if ( has_tag() ) :
					?>
					<span class="each-post-meta-info">
						<?php
						// In order to display the post's tag.
						$tags = get_the_tags();
						if ( ! empty( $tags ) ) {
							printf(
								/* translators: %s: tag page URL & the name of the post's first tag. */
								'<a href="%s" aria-label="' . esc_attr__( 'This Post has tag named: %s', 'tantyyellow' ) . '">%s</a>',
								esc_url( get_tag_link( $tags[0]->term_id ) ),
								esc_html( $tags[0]->name ),
								esc_html( $tags[0]->name )
							);
						}
						?>
					</span>
					<?php

				else :
					?>
					<span class="each-post-meta-info no-meta-info">
						<a tabindex="0" class="each-post-has-no-tag" aria-label="<?php esc_attr_e( 'This Post has no tag', 'tantyyellow' ); ?>">( <?php esc_html_e( 'None', 'tantyyellow' ); ?> )</a>
					</span>
					<?php

				endif;
				?>
			</p>



			<?php
			if ( is_single() ) :
				?>

			<!-- Each post author -->
			<p class="each-post-meta-thirdary">
				<span class="each-post-meta-name"><?php esc_html_e( 'AUTHOR', 'tantyyellow' ); ?></span>
				<span class="each-post-meta-info">
					<a href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); /* 'get_author_posts_url()' -> Get archive page of author's posts */ ?>" aria-label="
						<?php
						printf(
							/* translators: %s: The author of this post. */
							esc_attr__( 'This Post\'s Author is %s', 'tantyyellow' ),
							esc_attr( get_the_author() )
						);
						?>
					">
						<?php the_author(); ?>
					</a>
				</span>
			</p>

			<!-- Each post comments' number -->
			<p class="each-post-meta-forthary">

				<span class="each-post-meta-name">
					<?php esc_html_e( 'COMMENTS', 'tantyyellow' ); ?>
				</span>

				<span class="each-post-meta-info each-post-comments-number">

					<?php
					$all_comments_num = get_comments(
						array(
							'status'  => 'approve',
							'post_id' => get_the_ID(),
							'type'    => 'comment',
							'count'   => true,
						)
					);

					$all_comments_num_str = '';
					$has_comments_or_not  = 'each-post-has-comments';

					if ( 0 === $all_comments_num ) {

						$all_comments_num_str = '( ' . esc_html__( 'None', 'tantyyellow' ) . ' )';
						$has_comments_or_not  = 'each-post-has-no-comment';

					} elseif ( 1 === $all_comments_num ) {

						$all_comments_num_str = '1' . esc_html__( ' comment', 'tantyyellow' );

					} else {

						$all_comments_num_str = $all_comments_num . esc_html__( ' comments', 'tantyyellow' );

					}

					if ( comments_open() ) {
						?>
						<a href="#each-post-comment" class="<?php echo esc_attr( $has_comments_or_not ); ?>" aria-label="
							<?php
							printf(
								/* translators: %s: The comments' number of this post. */
								esc_attr__( 'The number of this post\'s comments is %s', 'tantyyellow' ),
								esc_attr( $all_comments_num_str )
							);
							?>
						">
							<?php echo esc_attr( $all_comments_num_str ); ?>
						</a>
						<?php
					} else {
						echo '<a tabindex="0" style="pointer-events: none; cursor: not-allowed;">' . esc_attr( $all_comments_num_str ) . '</a>';
					}
					?>
				</span>

			</p><!-- /.each-post-meta-forthary -->
				<?php
			endif;
			?>

		</div><!-- /.each-post-meta -->
		<?php
	endif;
}



/**
 * Output each post meta information, including...
 * ( post's categories, tags )
 * ( author, comments number ) if the page is single page
 *
 * @param string $content      Each post HTML DOM content.
 * @param string $details_link Switch the visibility of the post's details link.
 * @param string $loop_type    Whether main loop or sub loop.
 *
 * @return void
 */
function tantyyellow_output_template_parts_loop_each_post_content( $content, $details_link, $loop_type ) {
	?>
	<div class="<?php echo ( $content ) ? 'has-post-content' : 'has-no-post-content'; ?> each-post-content<?php echo ( ! is_single() ) ? ' clearfix' : ''; ?>">
		<?php
		if ( $content ) :
			?>
			<div class="each-post-content-inner">
				<?php
				if ( is_home() || is_archive() || is_search() ) :
					echo '<p class="loop-main">' . wp_kses_post( get_the_excerpt() ) . '</p>';

				elseif ( is_single() || is_page() ) :
					if ( 'main_loop' === $loop_type ) {

						// Show the entire content.
						the_content();

						// Add pagination if the content is divided into 2 or more pages.
						wp_link_pages(
							array(
								'before'         => '<div class="each-post-content-page-links">',
								'after'          => '</div>',
								'link_before'    => '<span>',
								'link_after'     => '</span>',
								'next_or_number' => 'number',
							)
						);

						if ( is_single() ) :
							// Show the complete list of categories.
							?>
							<div id="each-post-content-single-meta-cats" class="each-post-content-single-meta-each">
								<button id="each-post-content-single-meta-cats-title" class="each-post-content-single-meta-title avoiding-style-pollution" aria-label="<?php echo esc_attr__( 'Click this title to open or close the list of all categories that this post belongs to', 'tantyyellow' ); ?>">
									<?php esc_html_e( 'Post\'s All Categories', 'tantyyellow' ); ?>
								</button>

								<ul class="each-post-content-single-meta-info avoiding-style-pollution">

								<?php
								$categories = get_the_category();
								if ( ! empty( $categories ) ) {
									foreach ( $categories as $cat ) {
										printf(
											'<li><a href="%s" tabindex="-1">%s</a></li>',
											esc_url( get_category_link( $cat->term_id ) ),
											esc_html( $cat->cat_name )
										);
									}
								} else {
									echo '<li>( ' . esc_html__( 'None', 'tantyyellow' ) . ' )</li>';
								}
								?>
								</ul>
							</div>

							<?php
							// Show the complete list of tags.
							?>
							<div id="each-post-content-single-meta-tags" class="each-post-content-single-meta-each">
								<button id="each-post-content-single-meta-tags-title" class="each-post-content-single-meta-title avoiding-style-pollution" aria-label="<?php echo esc_attr__( 'Click this title to open or close the list of all tags that this post has', 'tantyyellow' ); ?>">
									<?php esc_html_e( 'Post\'s All Tags', 'tantyyellow' ); ?>
								</button>

								<ul class="each-post-content-single-meta-info avoiding-style-pollution">

								<?php
								$tags = get_the_tags();
								if ( ! empty( $tags ) ) {
									foreach ( $tags as $tag ) {
										printf(
											'<li><a href="%s" tabindex="-1">%s</a></li>',
											esc_url( get_category_link( $tag->term_id ) ),
											esc_html( $tag->name )
										);
									}
								} else {
									echo '<li>( ' . esc_html__( 'None', 'tantyyellow' ) . ' )</li>';
								}
								?>
								</ul>
							</div>
							<?php
						endif;

					} else {
						the_excerpt();
					}

				else :
					echo '<p>' . wp_kses_post( get_the_excerpt() ) . '</p>';

				endif;
				?>

				<?php
				else :
					?>
			<div class="each-post-content-inner">
				<p class="no-content">
					<br>
					<?php esc_html_e( 'No content exists.', 'tantyyellow' ); ?>
					<br>
				</p>

					<?php
			endif;
				?>

			</div>

	</div><!-- /.each-post-content -->

	<?php if ( is_user_logged_in() && ( 'without-details-link' !== $details_link ) ) : ?>
	<a class="each-post-details-link" href="<?php echo esc_url( get_permalink() ); ?>" aria-label="<?php echo esc_attr__( 'Click this link to move on to the single post\'s page for full content', 'tantyyellow' ); ?>">
		<p>...<?php esc_html_e( 'Details', 'tantyyellow' ); ?> &raquo</p>
	</a>
	<?php endif; ?>


	<?php
}



/**
 * Output message for 'No Post', 'No Document', 'No Result', etc.
 *
 * @return void
 */
function tantyyellow_output_template_parts_nothing_exists_message() {

	if ( is_home() ) :
		?>
	<section id="posts-loop-main-is-posts-home-page" class="posts-loop loop-main no-result">
		<hr>
		<h2><?php esc_html_e( 'No Post Exists.', 'tantyyellow' ); ?></h2>
		<hr>
		<p><?php esc_html_e( 'Sorry, but the post you are trying to see hasn\'t been found.', 'tantyyellow' ); ?></p>
		<p><?php esc_html_e( 'It seems that such a post doesn\'t exist, or has been removed.', 'tantyyellow' ); ?></p>

		<?php
	elseif ( is_single() ) :
		?>
	<section id="posts-loop-sub-is-single-page" class="posts-loop loop-sub has-no-posts">
		<hr>
		<h2><?php esc_html_e( 'No Post Exists.', 'tantyyellow' ); ?></h2>
		<hr>
		<p><?php esc_html_e( 'Sorry, but the post you are trying to see hasn\'t been found.', 'tantyyellow' ); ?></p>
		<p><?php esc_html_e( 'It seems that such a post doesn\'t exist, or has been removed.', 'tantyyellow' ); ?></p>

		<?php
	elseif ( is_attachment() ) :
		?>
	<section id="posts-loop-sub-is-attachment-page" class="posts-loop loop-sub has-no-posts">
		<hr>
		<h2><?php esc_html_e( 'No Attachment Exists.', 'tantyyellow' ); ?></h2>
		<hr>
		<p><?php esc_html_e( 'Sorry, but the attachment you are trying to see hasn\'t been found.', 'tantyyellow' ); ?></p>
		<p><?php esc_html_e( 'It seems that such an attachment doesn\'t exist, or has been removed.', 'tantyyellow' ); ?></p>

		<?php
	elseif ( is_search() ) :
		?>
	<section id="posts-loop-main-is-search-page" class="posts-loop loop-main no-result container">
		<hr>
		<h2><?php esc_html_e( 'No Result Exists.', 'tantyyellow' ); ?></h2>
		<hr>
		<p><?php esc_html_e( 'Sorry, but the result you are searching has not been found.', 'tantyyellow' ); ?></p>
		<p><?php esc_html_e( 'Please try again, or change searching keyword.', 'tantyyellow' ); ?></p>

		<?php
	elseif ( is_page() ) :
		?>
	<section id="posts-loop-main-is-page" class="posts-loop loop-main container has-no-content">
		<hr>
		<h2><?php esc_html_e( 'No Content Exists.', 'tantyyellow' ); ?></h2>
		<hr>
		<p><?php esc_html_e( 'Sorry, but the content of this page has not been found.', 'tantyyellow' ); ?></p>
		<p><?php esc_html_e( 'It seems that any content has not been added, or has been removed.', 'tantyyellow' ); ?></p>

		<?php
	else :
		?>
	<section class="posts-loop loop-main no-result container">
		<hr>
		<h2><?php esc_html_e( 'No Document Exists.', 'tantyyellow' ); ?></h2>
		<hr>
		<p><?php esc_html_e( 'Sorry, but the document you are trying to see hasn\'t been found.', 'tantyyellow' ); ?></p>
		<p><?php esc_html_e( 'It seems that such a document doesn\'t exist, or has been removed.', 'tantyyellow' ); ?></p>

		<?php
	endif;
	?>

	</section>

	<?php
}
