<?php
/**
 * This file contains a set of functions in order to define sanitizing & validating callback function.
 *
 * @package tantyyellow
 *
 * @link https://github.com/WPTT/code-examples/blob/master/customizer/sanitization-callbacks.php
 * @link https://gist.github.com/ControlledChaos/a68997f4a348d447132033332a4e50f1
 * @link https://make.wordpress.org/core/2016/07/05/customizer-apis-in-4-6-for-setting-validation-and-notifications/
 * @link https://anthonyskelton.com/2016/rediscover-wordpress-customizer/
 */

// ########################################################################################################################
// ##### Functions in order to sanitize ###################################################################################
// ########################################################################################################################

// ***** In order to define "sanitize_callback" function for theme customizer ***********************************

/**
 * "sanitizing callback" for <iframe>.
 *
 * @param string $string <iframe> content.
 *
 * @return string <iframe> content after sanitized with wp_kses()
 */
function tantyyellow_sanitize_iframe_callback( $string ) {
	$allowed_html = array(
		'a'      => array(
			'href' => array(),
		),
		'iframe' => array(
			'src'             => array(),
			'width'           => array(),
			'height'          => array(),
			'style'           => array(),
			'class'           => array(),
			'id'              => array(),
			'title'           => array(),
			'name'            => array(),
			'allowfullscreen' => array(),
			'scrolling'       => array(),
			'frameborder'     => array(),
			'marginwidth'     => array(),
			'marginheight'    => array(),
			'align'           => array(),
			'allow'           => array(),
			'longdesc'        => array(),
			'sandbox'         => array(),
			'srcdoc'          => array(),
		),
	);
	return wp_kses( $string, $allowed_html );
}



/**
 * "sanitizing callback" for image upload in order to clean the URL for database usage.
 *
 * @param string               $image_filename Image filename.
 * @param WP_Customize_Setting $setting        Setting instance.
 *
 * @link https://developer.wordpress.org/reference/functions/esc_url_raw/
 *
 * @return string The image filename if the extension is allowed; otherwise, the setting default.
 */
function tantyyellow_sanitize_image_ctrl_callback( $image_filename, $setting ) {
	return esc_url_raw( tantyyellow_validate_image_type( $image_filename, $setting->default ) );
}



/**
 * "sanitizing callback" for video upload in order to clean the URL for database usage.
 *
 * @param string               $video_filename Video filename.
 * @param WP_Customize_Setting $setting        Setting instance.
 *
 * @link https://developer.wordpress.org/reference/functions/esc_url_raw/
 *
 * @return string The video filename if the extension is allowed; otherwise, the setting default.
 */
function tantyyellow_sanitize_video_ctrl_callback( $video_filename, $setting ) {
	return esc_url_raw( tantyyellow_validate_video_type( $video_filename, $setting->default ) );
}



/**
 * "sanitizing callback" for select & radio.
 *
 * @param string $input   Slug to sanitize.
 *
 * @return string Sanitized input value.
 */
function tantyyellow_sanitize_select_radio_callback( $input ) {
	return esc_attr( $input );
}



/**
 * "sanitizing callback" for checkbox.
 * This callback sanitizes $input as a Boolean value, either TRUE or FALSE.
 *
 * @param boolean $checked Whether the checkbox is checked.
 *
 * @return boolean Whether the checkbox is checked.
 */
function tantyyellow_sanitize_checkbox_callback( $checked ) {
	return ( ( isset( $checked ) && true === $checked ) ? true : false );
}



/**
 * "sanitizing callback" for Number Range.
 *
 * This callback sanitizes`$number` as an absolute integer within a defined min-max range.
 *
 * @param int                  $number  Number to check within the numeric range defined by the setting.
 * @param WP_Customize_Setting $setting Setting instance.
 * @return int|string The number, if it is zero or greater and falls within the defined range; otherwise, the setting default.
 *
 * @see absint() https://developer.wordpress.org/reference/functions/absint/
 *
 * @link https://github.com/WPTT/code-examples/blob/master/customizer/sanitization-callbacks.php#L226 "Sanitize Number Range"
 */
function tantyyellow_sanitize_number_range_callback( $number, $setting ) {

	$number = absint( $number ); // Ensure input is an absolute integer.
	$atts   = $setting->manager->get_control( $setting->id )->input_attrs; // Get the input attributes associated with the setting.
	$min    = ( isset( $atts['min'] ) ? $atts['min'] : $number ); // Get minimum number in the range.
	$max    = ( isset( $atts['max'] ) ? $atts['max'] : $number ); // Get maximum number in the range.
	$step   = ( isset( $atts['step'] ) ? $atts['step'] : 1 ); // Get step.

	// If the number is within the valid range, return it; otherwise, return the default.
	return ( $min <= $number && $number <= $max && is_int( $number / $step ) ? $number : $setting->default );
}



// ########################################################################################################################
// ##### Functions in order to validate ###################################################################################
// ########################################################################################################################

// ***** In order to define "validate_callback" function for theme customizer ***********************************

/**
 * Checks the image's file extension and mime type against a whitelist.
 * If they're allowed, send back the filename, otherwise, return the setting default.
 *
 * @param string $image_filename Image filename.
 * @param string $default        Default value.
 *
 * @return string The image filename if the extension is allowed; otherwise, the setting default.
 */
function tantyyellow_validate_image_type( $image_filename, $default = '' ) {
	$mimes = array(
		'jpg|jpeg|jpe' => 'image/jpeg',
		'gif'          => 'image/gif',
		'png'          => 'image/png',
		'bmp'          => 'image/bmp',
		'tif|tiff'     => 'image/tiff',
		'ico'          => 'image/x-icon',
	);
	$file  = wp_check_filetype( $image_filename, $mimes );
	return ( $file['ext'] ? $image_filename : $default );
}



/**
 * Checks the video's file extension and mime type against a whitelist.
 * If they're allowed, send back the filename, otherwise, return the setting default.
 *
 * @param string $video_filename Video file name.
 * @param string $default        Default value.
 *
 * @return string The video filename if the extension is allowed; otherwise, the setting default.
 */
function tantyyellow_validate_video_type( $video_filename, $default = '' ) {
	$mimes = array(
		'asf|asx'      => 'video/x-ms-asf',
		'wmv'          => 'video/x-ms-wmv',
		'wmx'          => 'video/x-ms-wmx',
		'wm'           => 'video/x-ms-wm',
		'avi'          => 'video/avi',
		'divx'         => 'video/divx',
		'flv'          => 'video/x-flv',
		'mov|qt'       => 'video/quicktime',
		'mpeg|mpg|mpe' => 'video/mpeg',
		'mp4|m4v'      => 'video/mp4',
		'ogv'          => 'video/ogg',
		'webm'         => 'video/webm',
		'mkv'          => 'video/x-matroska',
	);
	$file  = wp_check_filetype( $video_filename, $mimes );
	return ( $file['ext'] ? $video_filename : $default );
}



/**
 * Validate whether or not the YouTube Video ID input by a user is valid.
 *
 * @param Object $validity Validity of input YouTube ID.
 * @param string $value    Input YouTube ID.
 *
 * @return Object Validity message.
 */
function tantyyellow_validate_youtube_video_id( $validity, $value ) {
	if ( ! empty( $value ) ) {
		if ( ( 0 === preg_match( '/[0-9A-Za-z_-]{10}[048AEIMQUYcgkosw]/', $value ) ) || ( 11 !== mb_strlen( $value, 'UTF-8' ) ) ) {
			$validity->add( 'youtube_video_id_format', esc_html__( 'YouTube Video ID is invalid.', 'tantyyellow' ) );
		}
	}
	return $validity;
}



/**
 * Validate whether or not the email address input by a user is valid.
 *
 * @param Object $validity Validity of input email address.
 * @param string $value    Input email address.
 *
 * @return Object Validity message.
 */
function tantyyellow_validate_email( $validity, $value ) {
	if ( ! empty( $value ) ) {
		if ( ! filter_var( $value, FILTER_VALIDATE_EMAIL ) ) {
			$validity->add( 'email_format', esc_html__( 'Email Address is invalid.', 'tantyyellow' ) );
		}
	}
	return $validity;
}



/**
 * Validate whether or not the phone number input by a user is valid.
 *
 * @param Object $validity Validity of input phone number.
 * @param string $value    Input phone number.
 *
 * @return Object Validity message.
 */
function tantyyellow_validate_phone_number( $validity, $value ) {
	if ( ! empty( $value ) ) {
		if (
			( 0 === preg_match( '/^[0-9\-\(\)\/\+\s]*$/', $value ) ) ||
			( 20 < mb_strlen( $value, 'UTF-8' ) ) ||
			( 6 > mb_strlen( $value, 'UTF-8' ) )
		) {
			$validity->add( 'phone_num_format', esc_html__( 'Phone Number is invalid.', 'tantyyellow' ) );
		}
	}
	return $validity;
}
