<?php
/**
 * "setups.php"
 *
 * @package tantyyellow
 */

// ########################################################################################################################
// ##### Functions in order to set up theme ###############################################################################
// ########################################################################################################################

// ***** In order to set up theme *******************************************************************************

/**
 * Define function for action hook "after_setup_theme".
 *
 * @link https://developer.wordpress.org/reference/functions/add_theme_support/
 * @link https://make.wordpress.org/core/2019/10/15/miscellaneous-developer-focused-changes-in-5-3/
 */
function tantyyellow_theme_support_after_setup_theme() {

	// +++++ In order to define 'Content Width'. ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
	// In order to ensure that no content or assets break the container of the site.
	// The content width sets the maximum allowed width for any content added to your site, including uploaded images.
	global $content_width;
	if ( ! isset( $content_width ) ) {
		$content_width = 1280;
	}

	// +++++ In order to load 'Theme textdomain' to localize language. ++++++++++++++++++++++++++++++++++++
	load_theme_textdomain( 'tantyyellow', get_stylesheet_directory() . '/languages' );

	// +++++ In order to enable support for menus +++++++++++++++++++++++++++++++++++++++++++++++++++++++++
	register_nav_menus(
		array(
			'header-navigation' => 'Header Navigation',
		)
	);

	// +++++ In order to enable plugins and themes to manage the document title tag +++++++++++++++++++++++
	add_theme_support( 'title-tag' );

	// +++++ In order to enable custom background color or image ++++++++++++++++++++++++++++++++++++++++++
	$args_custom_background = array(
		'default-color'          => 'ececec',
		'default-image'          => get_theme_file_uri( '/src/assets/media-files/images/default_images/default_site_background_img.jpg' ),
		'default-preset'         => 'default',
		'default-repeat'         => 'no-repeat',
		'default-position-x'     => 'center',
		'default-position-y'     => 'top',
		'default-size'           => 'cover',
		'default-attachment'     => 'fixed',
		'wp-head-callback'       => '_custom_background_cb',
		'admin-head-callback'    => '',
		'admin-preview-callback' => '',
	);
	add_theme_support( 'custom-background', $args_custom_background );

	// +++++ In order to add custom Logo function +++++++++++++++++++++++++++++++++++++++++++++++++++++++++
	add_theme_support(
		'custom-logo',
		array(
			'width'      => 900,
			'height'     => 250,
			'flex-width' => true,
		)
	);

	// +++++ In order to enable featured image ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
	add_theme_support( 'post-thumbnails' ); // which is required to enable 'Feature image'.

	// +++++ In order to set default block styles "Gutenberg" +++++++++++++++++++++++++++++++++++++++++++++
	add_theme_support( 'wp-block-styles' );

	// +++++ In order to set wide Alignment for "Gutenberg" +++++++++++++++++++++++++++++++++++++++++++++++
	add_theme_support( 'align-wide' );

	// +++++ In order not to output 'type=text/javascript' in <script> and 'type=text/css' in <link> ++++++
	add_theme_support( 'html5', array( 'script', 'style' ) );

	// +++++ In order to add default posts and comments RSS feed links to head ++++++++++++++++++++++++++++
	add_theme_support( 'automatic-feed-links' );

	// +++++ In order to define starter content +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
	add_theme_support( 'starter-content' );

	// +++++ In order to set post thumbnail size ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
	set_post_thumbnail_size( 480, 360, array( 'center', 'center' ) ); // set_post_thumbnail_size( $width, $height, $crop ) -> $crop(true: crop / false: resize).

	// +++++ In order to add new image size +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
	add_image_size( 'tantyyellow-single-page-thumbnail', 720, 360, array( 'center', 'center' ) );

}
add_action( 'after_setup_theme', 'tantyyellow_theme_support_after_setup_theme' ); // In order to hook 'tantyyellow_theme_support_after_setup_theme' after loading theme.



// ***** In order to register widget(s) (Not necessary to add to side area.) ************************************

/**
 * Define function for filter hook "widgets_init".
 */
function tantyyellow_widgets_init() {
	register_sidebar(
		array(
			'name'          => esc_html__( 'Main Sidebar', 'tantyyellow' ), // Any name.
			'id'            => 'main-sidebar',
			'description'   => esc_html__( 'Add widgets you want to display in sidebar at main section.', 'tantyyellow' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h5 class="widget-title focusable_elem" tabindex="0">',
			'after_title'   => '</h5>',
		)
	);
}
add_action( 'widgets_init', 'tantyyellow_widgets_init' );




// ***** In order to set up for posts content *******************************************************************

// +++++ In order to remove #more-000 anchor from the read-more link ++++++++++++++++++++++++++++++++++
/**
 * Define function for filter hook "the_content_more_link".
 *
 * @param string $link Read More link.
 */
function tantyyellow_remove_more_link_anchor( $link ) {
	$link = preg_replace( '/#more-[0-9]+/', '', $link );
	return $link;
}
add_filter( 'the_content_more_link', 'tantyyellow_remove_more_link_anchor' );



// +++++ In order to change excerpt length ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
/**
 * Define function for filter hook "excerpt_length".
 *
 * @param int $length The number of the length of excerpt.
 */
function tantyyellow_change_excerpt_length( $length ) {

	if ( is_admin() ) {
		return $length;

	} else {

		$excerpt_status = tantyyellow_get_site_basics_posts_each_post_archive_pages_excerpt_length_custom_length_onoff_value();
		$excerpt_length = tantyyellow_get_site_basics_posts_each_post_archive_pages_excerpt_length_num();

		if ( 'on' === $excerpt_status ) {
			return $excerpt_length;

		} else {

			$locale = get_locale();

			if ( 'ja' === $locale ) {
				return 120;

			} elseif ( ! ( false === strpos( $locale, 'en' ) ) ) {
				return 35;

			} else {
				return 55;
			}
		}
	}
}
add_filter( 'excerpt_length', 'tantyyellow_change_excerpt_length', 999 ); // Make sure to set the priority correctly, such as 999, else the default WordPress filter on this function will run last and override what you set here.



// ***** In order to change [...], which is generated when excerpt is applied. **********************************

/**
 * Define function for filter hook "excerpt_more".
 *
 * @param string $more The more text.
 */
function tantyyellow_change_excerpt_more( $more ) {
	if ( is_admin() ) {
		return $more;
	} else {
		return esc_html( '.....' );
	}
}
add_filter( 'excerpt_more', 'tantyyellow_change_excerpt_more' );




// ***** In order to output HTML for custom logo when using 'the_custom_logo()' *********************************

/**
 * Define function for filter hook "get_custom_logo".
 *
 * @link https://wordpress.stackexchange.com/questions/232174/how-to-change-get-custom-logo-url/232175
 *
 * @param string $html Custom logo HTML output.
 */
function tantyyellow_custom_logo_url( $html ) {

	$custom_logo_id = get_theme_mod( 'custom_logo' );
	$url            = home_url();
	$html           = sprintf(
		'<a href="%1$s" class="custom-logo-link" rel="home" itemprop="url">%2$s</a>',
		esc_url( $url ),
		wp_get_attachment_image(
			$custom_logo_id,
			'full',
			false,
			array(
				'class' => 'custom-logo',
			)
		)
	);
	return $html;
}
add_filter( 'get_custom_logo', 'tantyyellow_custom_logo_url' );



// ***** In order to modify the default template of the archive page title **************************************

/**
 * Define function for filter hook "get_the_archive_title".
 *
 * @param string $title Archive title to be displayed.
 */
function tantyyellow_get_the_archive_title( $title ) {

	$locale = get_locale();

	if ( is_category() ) {
		$title = single_cat_title( '', false );
	} elseif ( is_tag() ) {
		$title = single_tag_title( '', false );
	} elseif ( is_author() ) {
		$title = get_the_author();
	} elseif ( is_year() ) {
		if ( 'ja' === $locale ) {
			$title = get_the_date( 'Y' ) . esc_html__( 'seireki', 'tantyyellow' );
		} else {
			$title = get_the_date( 'Y' );
		}
	} elseif ( is_month() ) {
		if ( 'ja' === $locale ) {
			$title = get_the_date( 'Y' ) . esc_html__( 'seireki', 'tantyyellow' ) . get_the_date( 'n' ) . esc_html__( 'tsuki', 'tantyyellow' );
		} else {
			$title = get_the_date( 'F, Y' );
		}
	} elseif ( is_day() ) {
		if ( 'ja' === $locale ) {
			$title = get_the_date( 'Y' ) . esc_html__( 'seireki', 'tantyyellow' ) . get_the_date( 'n' ) . esc_html__( 'tsuki', 'tantyyellow' ) . get_the_date( 'j' ) . esc_html__( 'hinichi', 'tantyyellow' );
		} else {
			$title = get_the_date( 'F jS, Y' );
		}
	}
	return $title;
}
add_filter( 'get_the_archive_title', 'tantyyellow_get_the_archive_title' );



// ***** In order to remove classes from 'comment_class()' ******************************************************

/**
 * Define function for filter hook "comment_class".
 *
 * @param array $classes An array of comment classes.
 */
function tantyyellow_remove_comment_author_class( $classes ) {
	foreach ( $classes as $key => $class ) {
		if ( strstr( $class, 'comment-author-' ) ) { // Remove "comment author" class for security reason.
			unset( $classes[ $key ] );
		}
	}
	return $classes;
}
add_filter( 'comment_class', 'tantyyellow_remove_comment_author_class' );




// ***** In order to change category dropdown title *************************************************************

/**
 * Define function for filter hook "widget_categories_dropdown_args".
 *
 * @param array $cat_args An array of Categories widget drop-down arguments.
 */
function tantyyellow_change_category_dropdown_title( $cat_args ) {
	$cat_args['show_option_none'] = esc_html__( 'Select category', 'tantyyellow' );
	return $cat_args;
}
add_filter( 'widget_categories_dropdown_args', 'tantyyellow_change_category_dropdown_title' );




// ***** Add the theme prefix to the hooks defined in the WP core by default ************************************
// ***** and define the theme unique hooks, which has the same functions as the WP dafault ones. ****************
// ***** ( Ex. "wp_defined_hook_name" ==> "tantyyellow_wp_defined_hook_name" ) **********************************

/**
 * Define the theme unique "Filter Hook" name which hooks the functions as those 'the_title' hooks.
 * - This hook name 'tantyyellow_the_title' is used for apply_filters() in "class-tantyyellow-custom-walker-nav-menu.php".
 *
 * @see wp-includes\default-filters.php line:167
 * @see functions\classes\class-tantyyellow-custom-walker-nav-menu.php line:170 & 213
 */

/* ===== Must has the same functions as 'the_title' ========================================= */
add_filter( 'tantyyellow_the_title', 'wptexturize' );
add_filter( 'tantyyellow_the_title', 'convert_chars' );
add_filter( 'tantyyellow_the_title', 'trim' );

/* ===== Must has the same functions as 'wp_body_open' ====================================== */
add_action( 'tantyyellow_wp_body_open', 'wp_admin_bar_render', 0 );




add_action( 'tantyyellow_add_id_to_body_tag', 'tantyyellow_add_id_to_body_tag' );



/**
 * Output <link rel="prev/next"> for a page which is divided into 2 or more pages.
 *
 * @return void
 */
function tantyyellow_output_link_tag_rel_prev_next() {

	// If the page is a single post page or a static page.....
	if ( is_single() || is_page() ) {

		$multipage     = tantyyellow_get_max_num_pages_and_current_page();
		$max_num_pages = $multipage[0];

		// If the page is the top page or an archive page.....
	} else {

		$current_paged = get_query_var( 'paged' ) ? intval( get_query_var( 'paged' ) ) :
				( get_query_var( 'page' ) ? intval( get_query_var( 'page' ) ) : 1 );

		if ( get_previous_posts_link() ) {
			echo '<link rel="prev" href="' . esc_url( get_pagenum_link( $current_paged - 1 ) ) . '" />' . PHP_EOL;
		}

		if ( get_next_posts_link() ) {
			echo '<link rel="next" href="' . esc_url( get_pagenum_link( $current_paged + 1 ) ) . '" />' . PHP_EOL;
		}
	}
}
add_action( 'wp_head', 'tantyyellow_output_link_tag_rel_prev_next' );



/**
 * Get the the number of pages and the number of the current page.
 *
 * @return Array Numbers of pages & current page.
 */
function tantyyellow_get_max_num_pages_and_current_page() {
	$max_num_pages = substr_count( $GLOBALS['post']->post_content, '<!--nextpage-->' ) + 1;
	$current_page  = get_query_var( 'page' );
	return array( $max_num_pages, $current_page );
}



// ***** Set the arguments for $wp_query. ************************************************************************
/**
 * Set query arguments for each page.
 *
 * @param WP_Query $query WP Query.
 *
 * @return Array Arguments of the WP Query.
 *
 * @link https://developer.wordpress.org/reference/hooks/pre_get_posts/
 * @link https://qiita.com/_ruka_/items/e14280d34eddf49efad1
 */
function tantyyellow_set_query_args_for_each_page( $query ) {

	if ( is_admin() || ! $query->is_main_query() || is_preview() ) {
		return;
	}

	$query->set(
		'paged',
		( get_query_var( 'paged' ) ? intval( get_query_var( 'paged' ) ) : ( get_query_var( 'page' ) ? intval( get_query_var( 'page' ) ) : 1 ) )
	);

	$custom_num_onoff  = tantyyellow_get_site_basics_subsection_custom_posts_num_per_page_onoff_value();
	$custom_num_home   = tantyyellow_get_site_basics_subsection_custom_posts_num_per_page_home_num();
	$custom_num_search = tantyyellow_get_site_basics_subsection_custom_posts_num_per_page_search_results_num();
	$custom_num_cat    = tantyyellow_get_site_basics_subsection_custom_posts_num_per_page_cat_archive_num();
	$custom_num_tag    = tantyyellow_get_site_basics_subsection_custom_posts_num_per_page_tag_archive_num();
	$custom_num_author = tantyyellow_get_site_basics_subsection_custom_posts_num_per_page_author_archive_num();
	$custom_num_day    = tantyyellow_get_site_basics_subsection_custom_posts_num_per_page_day_archive_num();
	$custom_num_month  = tantyyellow_get_site_basics_subsection_custom_posts_num_per_page_month_archive_num();
	$custom_num_year   = tantyyellow_get_site_basics_subsection_custom_posts_num_per_page_year_archive_num();

	$default_num = get_option( 'posts_per_page' );

	if ( 'off' === $custom_num_onoff ) {
		$query->set( 'posts_per_page', $default_num );
		return;

	} elseif ( 'on' === $custom_num_onoff ) {

		/**
		 * Set the custom number of posts per page.
		 *
		 * @param WP_Query $_query         WP Query.
		 * @param WP_Query $_is_query_type Type of WP Query.
		 * @param int      $_custom_num    Custom number of posts per page.
		 * @param int      $_default_num   Default number of posts per page.
		 */
		function tantyyellow_set_posts_per_page_for_query_args( $_query, $_is_query_type, $_custom_num, $_default_num ) {
			if ( $_is_query_type ) {
				$_query->set( 'posts_per_page', ( $_custom_num ? $_custom_num : $_default_num ) );
				return;
			}
		}

		tantyyellow_set_posts_per_page_for_query_args( $query, $query->is_home(), $custom_num_home, $default_num );
		tantyyellow_set_posts_per_page_for_query_args( $query, $query->is_search(), $custom_num_search, $default_num );
		tantyyellow_set_posts_per_page_for_query_args( $query, $query->is_category(), $custom_num_cat, $default_num );
		tantyyellow_set_posts_per_page_for_query_args( $query, $query->is_tag(), $custom_num_tag, $default_num );
		tantyyellow_set_posts_per_page_for_query_args( $query, $query->is_author(), $custom_num_author, $default_num );
		tantyyellow_set_posts_per_page_for_query_args( $query, $query->is_day(), $custom_num_day, $default_num );
		tantyyellow_set_posts_per_page_for_query_args( $query, $query->is_month(), $custom_num_month, $default_num );
		tantyyellow_set_posts_per_page_for_query_args( $query, $query->is_year(), $custom_num_year, $default_num );

	}

}
add_action( 'pre_get_posts', 'tantyyellow_set_query_args_for_each_page' );
